# definition of the linguistic annotation steps

OGMIOSTMP	= $HOME/tmp

PLATFORM_ROOT	= $HOME/Platform

AWK		= /usr/bin/awk
PERL            = /usr/bin/perl

DEBUG           = 0

OUT_STREAM      = *STDOUT

<alvis_connection>
	HARVESTER_PORT	= 6234
	NEXTSTEP	= 0
	NEXTSTEP_HOST	= localhost
	NEXTSTEP_PORT	= 7345
	SPOOLDIR	= $HOME/tmp/spool
	OUTDIR		= $HOME/tmp/Outdir
</alvis_connection>

<NLP_connection>
	SERVER			= localhost
	PORT			= 1510
	RETRY_CONNECTION	= 10
</NLP_connection>

<XML_INPUT>
    PRESERVEWHITESPACE = 0
    LINGUISTIC_ANNOTATION_LOADING = 1
    FILEFORMAT = ALVIS
</XML_INPUT>


<XML_OUTPUT>
    FORM = 1
    ID = 1
    TOKEN_LEVEL = 1
    SEMANTIC_UNIT_NAMED_ENTITY_LEVEL	= 1
    WORD_LEVEL	= 1
    SENTENCE_LEVEL = 1
    MORPHOSYNTACTIC_FEATURE_LEVEL	= 1
    LEMMA_LEVEL	= 1
    SEMANTIC_UNIT_TERM_LEVEL	= 1
    SEMANTIC_UNIT_LEVEL	= 1
    SYNTACTIC_RELATION_LEVEL	= 1
    DOMAIN_SPECIFIC_RELATION_LEVEL	= 1
    SECTION_LEVEL = 1 # 0


      # NO_STD_XML_OUTPUT = ARFF  # XML output Yatea
#      NO_STD_XML_OUTPUT = EVAL  # XML output Yatea
#      NO_STD_XML_OUTPUT = GW  # XML output Yatea
#  NO_STD_XML_OUTPUT = "TAGGEDSENT" #
NO_STD_XML_OUTPUT = "TXT" #
#     NO_STD_XML_OUTPUT = 2 # termlistoutput
#    NO_STD_XML_OUTPUT = 3 # HTML output (corpus and tagged terms)
#    NO_STD_XML_OUTPUT = "XML"

#        NO_STD_XML_OUTPUT = 7 # TTG output
#        NO_STD_XML_OUTPUT = 5 # Txt output
#        NO_STD_XML_OUTPUT = 6 # TTG output
#        NO_STD_XML_OUTPUT = 8 # TTG output
#         NO_STD_XML_OUTPUT = 9 # DOT outout
#         NO_STD_XML_OUTPUT = 10 # FF + TTG output

#     YATEA = 1
</XML_OUTPUT>

<linguistic_annotation>
	ENABLE_TOKEN	= 1
	ENABLE_NER	= 1
	ENABLE_WORD	= 1
	ENABLE_SENTENCE = 1
	ENABLE_POS	= 1
	ENABLE_LEMMA	= 1
	ENABLE_TERM_TAG	= 1
	ENABLE_SYNTAX	= 0
	ENABLE_SEMANTIC_TAG	= 0
#      <processing>
#        id       = 22
#        order    = 1
#        tool     = "Section Identification"
#        comments = "Section Identification"
#      </processing>
    # <processing>
    #   id       = 2
    #   order    = 1
    #   tool     = "I2B2 Named Entity Recognizer"
    #   comments = "Named Entity Recognition"
    # </processing>
    # <processing>
    #   id       = 2
    #   order    = 1
    #   tool     = "DEFT 2013 Named Entity Recognizer"
    #   comments = "Named Entity Recognition"
    # </processing>
#     <processing>
#       id       = 3
#       order    = 1
#       tool     = TagEN
#       comments = "Named Entity Recognition"
#     </processing>
#     <processing>
#       id       = 4
#       order    = 2
#       tool     = "Ukrainian Word Segmentizer"
#       comments = "Word segmentation for Ukrainian"
#     </processing>
    # <processing>
    #   id       = 4
    #   order    = 2
    #   tool     = "Awk Word Segmentizer"
    #   comments = "Word segmentation"
    # </processing>
    <processing>
      id       = 4
      order    = 2
      tool     = "Perl Word Segmentizer"
      comments = "Word segmentation"
    </processing>
    <processing>
      id       = 5
      order    = 3
      tool     = "Basic internal Sentence Segmentizer"
      comments = "Sentence segmentation"
    </processing>
    <processing>
      id       = 6
      order    = 4
      tool     = "TreeTagger"
      comments = "POS tagger"
    </processing>
#     <processing>
#       id       = 18
#       order    = 5
#       tool     = "Flemm"
#       comments = "POS tagger and morphological analyser"
#     </processing>
#     <processing>
#       id       = 8
#       order    = 5
#       tool     = "PorterStemmer"
#       comments = "Word Stemming"
#     </processing>
     # <processing>
     #   id       = 9
     #   order    = 6
     #   tool     = "TermTagger"
     #   comments = "Term Tagger"
     # </processing>
#     <processing>
#       id       = 6
#       order    = 3
#       tool     = "I2B2 Sentence Segmentizer"
#       comments = "Sentence segmentation for I2B2"
#     </processing>
     # <processing>
     #   id       = 7
     #   order    = 4
     #   tool     = "GeniaTagger"
     #   comments = "Genia POS Tagger"
     # </processing>
#      <processing>
#        id       = 8
#        order    = 6
#        tool     = "StanfordParser"
#        comments = "Syntactic Parser"
#      </processing>
#     <processing>
#       id       = 14
#       order    = 8
#       tool     = "I2B2 2010 Relation Acquisition"
#       comments = "I2B2 2010 Relation Acquisition"
#     </processing>
    # <processing>
    #   id       = 10
    #   order    = 7
    #   tool     = "Distribution"
    #   comments = "Distribution analysis preparation"
    # </processing>

    <processing>
      id       = 10
      order    = 7
      tool     = "YaTeA"
      comments = "Term Extractor"
    </processing>
    # <processing>
    #   id       = 12
    #   order    = 9
    #   tool     = "LexicalSyntacticPatterns"
    #   comments = "Application of Lexical Syntactic Patterns"
    # </processing>

#      <processing>
#        id       = 16
#        order    = 6
#        tool     = "I2B22010ConceptTagging"
#        comments = "I2B2 2010 concept tagging based on results"
#      </processing>
#      <processing>
#        id       = 17
#        order    = 8
#        tool     = "I2B2AssertionIdentification"
#        comments = "I2B2 Assertion Identification"
#      </processing>
#      <processing>
#        id       = 11
#        order    = 9
#        tool     = "MorphoSemanticTagging"
#        comments = "Semantic tagging based on morphological and lexical clues"
#      </processing>

#     <processing>
#       id       = 20
#       order    = 100
#       tool     = "I2B2 2010 Post Processing"
#       comments = "Post Processing for the 2010 I2B2 Challenge"
#     </processing>

    # <processing>
    #   id       = 20
    #   order    = 100
    #   tool     = "I2B2 2012 Post Processing"
    #   comments = "Post Processing for the 2012 I2B2 Challenge"
    # </processing>

#     <processing>
#       id       = 11
#       order    = 8
#       tool     = Faster
#       comments = "Morphosyntactic variants acquisition"
#     </processing>

#     <processing>
#       id       = 20
#       order    = 100
#       tool     = "I2B2 Post Processing"
#       comments = "Post Processing for the 2009 I2B2 Challenge"
#     </processing>

#     <processing>
#       id       = 21
#       order    = 50
#       tool     = "Skill Identification"
#       comments = "Skills identification for the BQR ICED"
#     </processing>

    # <processing>
    #   id       = 22
    #   order    = 50
    #   tool     = "Skill production"
    #   comments = "Production of a ressource of Skills for the BQR ICED after term extractor"
    # </processing>

    # <processing>
    #   id       = 23
    #   order    = 100
    #   tool     = "Skerou"
    #   comments = "Output form Skerou"
    # </processing>

    # <processing>
    #   id       = 21
    #   order    = 99
    #   tool     = "DEFT 2012 Challenge"
    #   comments = "Post Processing for the DEFT 2012 Challenge"
    # </processing>

</linguistic_annotation>

<NLP_misc>
	NLP_resources	= $PLATFORM_ROOT/Resources
	SAVE_IN_OUTDIR	= 1
	TERM_LIST_EN	= $NLP_resources/terms.txt.sav
	TERM_LIST_FR	= $NLP_resources/terms_FR.txt
    # valid tags for each language
    <POSTAG_LIST>
        <EN>
	    CC = 1
	    CD = 1
    	    DT = 1
            EX = 1
            FW = 1
            IN = 1
            JJ = 1
            JJR = 1
            JJS = 1
            LS = 1
            MD = 1
            NN = 1
            NNS = 1
            NP = 1
            NPS = 1
            PDT = 1
            POS = 1
            PP = 1
            PP$ = 1
            RB = 1
            RBR = 1
            RBS = 1
            RP = 1
            SYM = 1
            TO = 1
            UH = 1
            VB = 1
            VBD = 1
            VBG = 1
            VBN = 1
            VBP = 1
            VBZ = 1
            VV = 1
            VVD = 1
            VVG = 1
            VVN = 1
            VVP = 1
            VVZ = 1
            WDT = 1
            WP = 1
            WP$ = 1
            WRB = 1
        </EN>
        
        <FR>
            ABR = 1
            ADJ = 1
            ADV = 1
            DET:ART = 1
            DET:POS = 1
            INT = 1
            KON = 1
            NAM = 1
            NOM = 1
            NUM = 1
            PRO = 1
            PRO:DEM = 1
            PRO:IND = 1
            PRO:PER = 1
            PRO:POS = 1
            PRO:REL = 1
            PRP = 1
            PRP:det = 1
            PUN = 2
            PUN:cit = 2
            SENT = 2
            SYM = 1
            VER:cond = 1
            VER:futu = 1
            VER:impe = 1
            VER:impf = 1
            VER:infi = 1
            VER:pper = 1
            VER:ppre = 1
            VER:pres = 1
            VER:simp = 1
            VER:subi = 1
            VER:subp = 1
        </FR>
        
    </POSTAG_LIST>
</NLP_misc>

# TO KEEP
NLP_tools_root = $PLATFORM_ROOT/NLPtools
NLP_resources_root = $PLATFORM_ROOT/Resources
#


SEMTAG_EN_DIR = $NLP_tools_root/AlvisSemTag-0.4
ONTOLOGY = $SEMTAG_EN_DIR/share/Subtilis_Molecular_Biology-v2.rdf
CANONICAL_DICT = $SEMTAG_EN_DIR/share/canonical_head_variants.dict.trish2 # optional
PARENT_DICT = $SEMTAG_EN_DIR/share/Subtilis_Molecular_Biology-v2.parent.trish2 # optional

<NLP_tools>
	NETAG_EN		= "$NLP_tools_root/TagEN/tagen -t -y :bio"
	NETAG_FR		= "$NLP_tools_root/TagEN/tagen -t -y :equer"
	WORDSEG_EN		= "$AWK -f $NLP_tools_root/WordSeg/words-en.awk"
	# WORDSEG_EN		= "$NLP_tools_root/WordSeg/sentences.pl"
	WORDSEG_FR		= "$AWK -f $NLP_tools_root/WordSeg/words-fr.awk"
	#POSTAG_EN		= "$NLP_tools_root/TreeTagger/bin/tree-tagger $NLP_tools_root/TreeTagger/lib/english.par -token -lemma -sgml -no-unknown"
	#POSTAG_EN		= "(cd $NLP_tools_root/geniatagger-2.0.1; sed 's/ /___/g' | tr '\n' ' '| ./geniatagger -nt | cut -f 1,2,3|sed 's/\([^\t]*\t\)\([^\t]*\)\t\([^\t]*\)/\1\3\t\2/g' | sed 's/___/ /g' | grep -v '^$')"
	POSTAG_FR		= "$NLP_tools_root/TreeTagger/bin/tree-tagger $NLP_tools_root/TreeTagger/lib/french.par -token -lemma -sgml -no-unknown"
	SYNTACTIC_PATH_EN	= "$NLP_tools_root/link-4.1b"
	# SYNTACTIC_PATH_EN       = "$NLP_tools_root/biolgForAlvis/biolg-1.1.7b"
	SYNTACTIC_PATH_FR	= ""
	SYNTACTIC_ANALYSIS_EN	= "cd $SYNTACTIC_PATH_EN ; $SYNTACTIC_PATH_EN/parse"

# 	SYNTACTIC_PATH_EN_SUPPL       = "/home/thierry/Recherche/Logiciels/LP2LP"
#         SYNTACTIC_ANALYSIS_EN_LP2LP_CLEAN       = "cd $SYNTACTIC_PATH_EN_SUPPL ; $SYNTACTIC_PATH_EN_SUPPL/clean_BioLG_output_for_lp2lp.pl"
#         SYNTACTIC_ANALYSIS_EN_LP2LP     = "cd $SYNTACTIC_PATH_EN_SUPPL ; $SYNTACTIC_PATH_EN_SUPPL/lp2lp/lp2lp -r $SYNTACTIC_PATH_EN_SUPPL/lp2lp/test/lp2lp.conf"

	# SYNTACTIC_ANALYSIS_EN	= "cd $SYNTACTIC_PATH_EN ; $SYNTACTIC_PATH_EN/parse -xmlin"
	SYNTACTIC_ANALYSIS_FR	= ""
	TERM_TAG_FR		= ""
	TERM_TAG_EN		= ""
        SEMTAG_EN               = "$SEMTAG_EN_DIR/src/AlvisSemTag -c $CANONICAL_DICT -p $PARENT_DICT -o $ONTOLOGY"
        SEMTAG_FR               = ""
        YATEARC                 = "/etc/yatea/yatea.rc"
        YATEAOUTPUT             = "$ALVISTMP"
        <TOOL>
            NAME                = "TagEN"
            VERSION             = "1"
            COMMENTS            = "Named Entity Recognizer"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::TagEN"
            <CONFIGURATION>
               <CONFIG language=EN>
                   TAGENCONF = "$NLP_tools_root/TagEN/tagen.conf"
               </CONFIG>
               <CONFIG language=FR>
                   TAGENCONF = "$NLP_tools_root/TagEN/tagen.conf"
               </CONFIG>
               <COMMANDS language=EN>
                   TAGENMODE               = ":bio"
                   TAGEN_CMD               = "$NLP_tools_root/TagEN/tagen -t -y $TAGENMODE"
               </COMMANDS>
               <COMMANDS language=FR>
                   TAGENMODE               = ":equer"
                   TAGEN_CMD               = "$NLP_tools_root/TagEN/tagen -t -y $TAGENMODE"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "Awk Word Segmentizer"
            VERSION             = "1"
            COMMENTS            = "Word segmentizer"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::AwkWordSegmentizer"
            <CONFIGURATION>
               <COMMANDS language=SV>
                   WordSegmentizer_CMD       = "$AWK -f $NLP_tools_root/WordSeg/words-en.awk"
               </COMMANDS>
#                <COMMANDS language=UK>
#                    WordSegmentizer_CMD       = "$AWK -f $NLP_tools_root/WordSeg/words-en.awk"
#                </COMMANDS>
               <COMMANDS language=EN>
                   WordSegmentizer_CMD       = "$AWK -f $NLP_tools_root/WordSeg/words-en.awk"
               </COMMANDS>
               <COMMANDS language=FR>
                   WordSegmentizer_CMD       = "$AWK -f $NLP_tools_root/WordSeg/words-fr.awk"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "Perl Word Segmentizer"
            VERSION             = "0.1"
            COMMENTS            = "Word segmentizer"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::PerlWordSegmentizer"
            <CONFIGURATION>
               <COMMANDS language=SV>
                   WordSegmentizer_CMD       = "$PERL $NLP_tools_root/WordSeg/words-en.pl"
               </COMMANDS>
               <COMMANDS language=EN>
                   WordSegmentizer_CMD       = "$PERL $NLP_tools_root/WordSeg/words-en.pl"
               </COMMANDS>
               <COMMANDS language=FR>
                   WordSegmentizer_CMD       = "$PERL $NLP_tools_root/WordSeg/words-fr.pl"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "Ukrainian Word Segmentizer"
            VERSION             = "1"
            COMMENTS            = "Word segmentizer for ukrainian"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::UKWordSegmentizer"
            <CONFIGURATION>
               <COMMANDS language=UK>
                   WordSegmentizer_CMD       = "/bin/false"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "Basic internal Sentence Segmentizer"
            VERSION             = "1"
            COMMENTS            = "Very basic intenal segmentizer"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::BasicSentenceSegmentizer"
            <CONFIGURATION>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <CONFIG language=SV>
                  SENTENCESEPARATORCHARLIST = "!?."
               </CONFIG>
               <COMMANDS language=EN>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <CONFIG language=EN>
                  SENTENCESEPARATORCHARLIST = "!?."
               </CONFIG>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
               <CONFIG language=FR>
                  SENTENCESEPARATORCHARLIST = "!?."
               </CONFIG>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "I2B2 Named Entity Recognizer"
            VERSION             = "1"
            COMMENTS            = "Named Entity Recognizer dedicated to the I2B2 challenge - medical textual data"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2NER"
            <CONFIGURATION>
               <CONFIG language=EN>
                   MERGE = 0
               </CONFIG>
               <CONFIG language=FR>
                   MERGE = 1
               </CONFIG>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
               </COMMANDS>
               <RESOURCE language=EN>
#                       MEDICATION = ""
#                       REASON = ""
                        MODEADM_LIST = "$HOME/Research/Resources/I2B2-2010/ModeAdm.txt"
                        DOSAGE_LIST = "$HOME/Research/Resources/I2B2-2010/Dosage.txt"
                        FREQUENCY_LIST = "$HOME/Research/Resources/I2B2-2010/Frequency.txt"
                        DURATION_LIST = "$HOME/Research/Resources/I2B2-2010/Duration.txt"
                        ANONYMIZEDNAME_LIST = "$HOME/Research/Resources/I2B2-2010/AnonymiszedNames.txt"
                        URL_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/URLs.txt"
                        DATE_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Dates.txt"
                        WEIGHT_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Weights.txt"
                        VOLUME_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Volumes.txt"
               </RESOURCE>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "DEFT 2013 Named Entity Recognizer"
            VERSION             = "1"
            COMMENTS            = "Named Entity Recognizer dedicated to the DEFT 2013 challenge"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::DEFT2013NER"
            <CONFIGURATION>
               <CONFIG language=EN>
                   MERGE = 0
               </CONFIG>
               <CONFIG language=FR>
                   MERGE = 1
               </CONFIG>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
               </COMMANDS>
               <RESOURCE language=EN>
#                       MEDICATION = ""
#                       REASON = ""
                        # MODEADM_LIST = "$HOME/Research/Resources/I2B2-2010/ModeAdm.txt"
                        # DOSAGE_LIST = "$HOME/Research/Resources/I2B2-2010/Dosage.txt"
                        # FREQUENCY_LIST = "$HOME/Research/Resources/I2B2-2010/Frequency.txt"
                        # DURATION_LIST = "$HOME/Research/Resources/I2B2-2010/Duration.txt"
                        # ANONYMIZEDNAME_LIST = "$HOME/Research/Resources/I2B2-2010/AnonymiszedNames.txt"
                        # URL_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/URLs.txt"
                        # DATE_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Dates.txt"
                        # WEIGHT_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Weights.txt"
                        # VOLUME_LIST = "$THHOME/Research/Projets/BQR/Fora/Resources/Doctissimo/Volumes.txt"
                        QUANTITY_LIST = "$HOME/Research/Challenges/2013DEFT/Resources/quantities.txt"
               </RESOURCE>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "I2B2 Sentence Segmentizer"
            VERSION             = "1"
            COMMENTS            = "Specific sentencesegmentizer for I2B2"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2SentenceSegmentizer"
            <CONFIGURATION>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "I2B2 Post Processing"
            VERSION             = "1"
            COMMENTS            = "Post Processing for the I2B2 challenge - medical textual data"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2PostProcessing"
            <CONFIGURATION>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
               </COMMANDS>
               <RESOURCE language=EN>
                    CORRESP     = "$HOME/Research/Challenges/I2B2-2010/Resources/Correspondances.rc"
                    MEDSECTION  = "$HOME/Research/Challenges/I2B2-2010/Resources/MedicationSections-v2.rc"
                    INDEX       = "$HOME/Research/Challenges/I2B2-2010/Data/TrainingSets"
                    STOPWORDS    = "$THHOME/Research/Challenges/I2B2-2009/TESTS/RUNS/Config+Ressources/RUN6/stopword.en.big"
                    MEDENDINGSBI  = "$THHOME/Research/Challenges/I2B2-2009/TESTS/RUNS/Config+Ressources/RUN6/finales-bi-meds.txt"
                    MEDENDINGSTRI = "$THHOME/Research/Challenges/I2B2-2009/TESTS/RUNS/Config+Ressources/RUN6/finales-tri-meds.txt"
               </RESOURCE>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "I2B2 2012 Post Processing"
            VERSION             = "1"
            COMMENTS            = "Post Processing for the 2012 I2B2 challenge - medical textual data"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2PostProcessing2012"
            <CONFIGURATION>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
               </COMMANDS>
               <CONFIG language=EN>
                     TERMFILTERING = "iTer"
                     TERMFILTERING_VALUE = 0.4
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <RESOURCE language=EN>
                      CORRESP_R     = "$LOCALHOME/2012I2B2/Resources/Correspondances-rel.rc"
                      CORRESP_CA     = "$LOCALHOME/2012I2B2/Resources/Correspondances.rc"
                      # STOPWORDS     = "$LOCALHOME/2012I2B2/Resources/noterms.txt"
                      NORMALITY     = "$LOCALHOME/2012I2B2/Resources/normality.txt"
                     MEDSECTION  = "$LOCALHOME/2012I2B2/Resources/MedicationSections-v3.rc"
                     INDEX       = "$LOCALHOME/2012I2B2/Data/Input"
                     DESTDIR     = "$LOCALHOME/2012I2B2/Data/Output"
                     OUTPUTTYPE  = "C"
                                  # C, A, R
               </RESOURCE>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "I2B2 2010 Post Processing"
            VERSION             = "1"
            COMMENTS            = "Post Processing for the 2010 I2B2 challenge - medical textual data"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2PostProcessing2010"
            <CONFIGURATION>
               <COMMANDS language=SV>
                    WSSegmentizer_CMD       = ""
               </COMMANDS>
               <COMMANDS language=EN>
               </COMMANDS>
               <CONFIG language=EN>
                     TERMFILTERING = "iTer"
                     TERMFILTERING_VALUE = "0.5"
                   <SEMANTICTYPES>
                       SEMANTICTYPE = "problem"
#                        SEMANTICTYPE = "function"
                       # SEMANTICTYPE = "Behavior"
                       # SEMANTICTYPE = "Biologically Active Substance"
                       # SEMANTICTYPE = "Biologic Function"
                       # SEMANTICTYPE = "Body Space or Junction"
                       # SEMANTICTYPE = "Cell"
                       # SEMANTICTYPE = "Cell Component"
                       # SEMANTICTYPE = "Cell Function"
                       # SEMANTICTYPE = "Conceptual Entity"
                       # SEMANTICTYPE = "Finding"
                       # SEMANTICTYPE = "Functional Concept"
                       # SEMANTICTYPE = "Genetic Function"
                       # SEMANTICTYPE = "Individual Behavior"
                       # SEMANTICTYPE = "Mental or Behavioral Dysfunction"
                       # SEMANTICTYPE = "Mental Process"
                       # SEMANTICTYPE = "Molecular Function"
                       # SEMANTICTYPE = "Natural Phenomenon or Process"
                       # SEMANTICTYPE = "Organism Function"
                       # SEMANTICTYPE = "Organ or Tissue Function"
                       # SEMANTICTYPE = "Pathologic Function"
                       # SEMANTICTYPE = "Pharmacologic Substance"
                       # SEMANTICTYPE = "Phenomenon or Process"
                       # SEMANTICTYPE = "Physiologic Function"
                       # SEMANTICTYPE = "Qualitative Concept"
                       # SEMANTICTYPE = "Social Behavior"
                       # SEMANTICTYPE = "Temporal Concept"
                       # SEMANTICTYPE = "Tissue"
                       # SEMANTICTYPE = "Disease or Syndrome"
                       # SEMANTICTYPE = "Enzyme"
                       # SEMANTICTYPE = "Gene or Genome"
                       # SEMANTICTYPE = "Immunologic Factor"
                       # SEMANTICTYPE = "Organism Attribute"
                   </SEMANTICTYPES>
                   LOADINDEX = 1
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <RESOURCE language=EN>
                      CORRESP_R     = "$HOME/Research/Challenges/I2B2-2010/Resources/Correspondances-rel.rc"
                      CORRESP_CA     = "$HOME/Research/Challenges/I2B2-2010/Resources/Correspondances.rc"
                      STOPWORDS     = "$HOME/Research/Challenges/I2B2-2010/Resources/noterms.txt"
                      NORMALITY     = "$HOME/Research/Challenges/I2B2-2010/Resources/normality.txt"
                     MEDSECTION  = "$HOME/Research/Challenges/I2B2-2010/Resources/MedicationSections-v3.rc"
                     INDEX       = "$HOME/Research/Challenges/I2B2-2010/Training/ProcessAnnot"
                     DESTDIR     = "$HOME/Research/Challenges/I2B2-2010/Training/RESULTS/AST/RUN28-SVM1"
                     OUTPUTTYPE  = "A"
                                  # C, A, R
               </RESOURCE>
               <COMMANDS language=FR>
                   WSSegmentizer_CMD       = ""
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "TreeTagger"
            VERSION             = "3.1"
            COMMENTS            = "Decision TreeTagger POS tagger"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::TreeTagger"
            <CONFIGURATION>
               <COMMANDS language=EN>
                    TreeTagger_PARAMETER_FILE   = "$NLP_tools_root/TreeTagger/lib/english.par"
                    TreeTagger_PARAMETERS       = "-token -lemma -sgml -no-unknown"
                    TreeTagger_BIN       = "$NLP_tools_root/TreeTagger/bin/tree-tagger"
                    TreeTagger_CMD       = "$TreeTagger_BIN $TreeTagger_PARAMETER_FILE $TreeTagger_PARAMETERS"
               </COMMANDS>
               <COMMANDS language=FR>
                    TreeTagger_PARAMETER_FILE   = "$NLP_tools_root/TreeTagger/lib/french.par"
                    TreeTagger_PARAMETERS       = "-token -lemma -sgml -no-unknown"
                    TreeTagger_BIN       = "$NLP_tools_root/TreeTagger/bin/tree-tagger"
                    TreeTagger_CMD       = "$TreeTagger_BIN $TreeTagger_PARAMETER_FILE $TreeTagger_PARAMETERS"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "GeniaTagger"
            VERSION             = "2.0.1"
            COMMENTS            = "Genia POS tagger"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::GeniaTagger"
            <CONFIGURATION>
               <COMMANDS language=EN>
                    GeniaTagger_BIN       = "./geniatagger"
                    GeniaTagger_DIR      = "$NLP_tools_root/geniatagger-2.0.1"
                    GeniaTagger_CMD       = "(cd $GeniaTagger_DIR; $GeniaTagger_BIN -nt)"
               </COMMANDS>
               <COMMANDS language=FR>
                    TreeTagger_PARAMETER_FILE   = "$NLP_tools_root/TreeTagger/lib/french.par"
                    TreeTagger_PARAMETERS       = "-token -lemma -sgml -no-unknown"
                    TreeTagger_BIN       = "$NLP_tools_root/TreeTagger/bin/tree-tagger"
                    TreeTagger_CMD       = "$TreeTagger_BIN $TreeTagger_PARAMETER_FILE $TreeTagger_PARAMETERS"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        # <TOOL>
        #     NAME                = "GeniaTagger"
        #     VERSION             = "2.0.1"
        #     COMMENTS            = "Genia POS tagger"
        #     WRAPPER             = "Lingua::Ogmios::NLPWrappers::TreeTagger"
        #     <CONFIGURATION>
        #        <COMMANDS language=EN>
        #             # TreeTagger_PARAMETER_FILE   = "$NLP_tools_root/TreeTagger/lib/english.par"
        #             # TreeTagger_PARAMETERS       = "-token -lemma -sgml -no-unknown"
        #             GeniaTagger_BIN       = "./geniatagger"
        #             GeniaTagger_DIR      = "$NLP_tools_root/geniatagger-2.0.1"
        #             TreeTagger_CMD       = "(cd $GeniaTagger_DIR; sed 's/ /___/g' | tr '\n' ' '| $GeniaTagger_BIN -nt | cut -f 1,2,3|sed 's/\([^\t]*\t\)\([^\t]*\)\t\([^\t]*\)/\1\3\t\2/g' | sed 's/___/ /g' | grep -v '^$')"
        #        </COMMANDS>
        #        <COMMANDS language=FR>
        #             # TreeTagger_PARAMETER_FILE   = "$NLP_tools_root/TreeTagger/lib/french.par"
        #             # TreeTagger_PARAMETERS       = "-token -lemma -sgml -no-unknown"
        #             # TreeTagger_BIN       = "$NLP_tools_root/TreeTagger/bin/tree-tagger"
        #             # TreeTagger_CMD       = "$TreeTagger_BIN $TreeTagger_PARAMETER_FILE $TreeTagger_PARAMETERS"
        #        </COMMANDS>
        #     </CONFIGURATION>
        # </TOOL>
        <TOOL>
            NAME                = "PorterStemmer"
            VERSION             = "1"
            COMMENTS            = "Stemming with the Porter' algorithm"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::PorterStemmer"
            <CONFIGURATION>
               <COMMANDS language=EN>
                    PerlModule  = "Lingua::Stem"
               </COMMANDS>
               <COMMANDS language=FR>
                    PerlModule  = "Lingua::Stem"
               </COMMANDS>
               <COMMANDS language=SV>
                    PerlModule  = "Lingua::Stem"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "TermTagger"
            VERSION             = "0.5"
            COMMENTS            = "Simple Term Tagger"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::TermTagger"
            <CONFIGURATION>
               <CONFIG language=EN>
                   MERGE_TERMS = 1
                   LEMMA = 1
                   CASE_SENSITIVE = 3
               </CONFIG>
               <CONFIG language=FR>
                   MERGE_TERMS = 1
                   LEMMA = 1
                   CASE_SENSITIVE = 3
               </CONFIG>
               <COMMANDS language=EN>
                     # TERMLIST   = 
                    TERMLIST    = "$NLP_resources_root/terms.txt.sav"
                    # TERMLIST    = "$THHOME/Research/Challenges/I2B2-2009/TESTS/RUNS/Config+Ressources/RUN6/Medication+Reason+Negation+SNOMED-DMWithoutType+ReasonMarkers.txt"
#                     TERMLIST    = "$HOME/Research/Divers/Geneve/Resources/terms.list"
#                     TERMLIST    = "$HOME/Research/Challenges/I2B2-2010/Resources/VJul2010/marqueurs_assertions_tot"
#                     TERMLIST    = "$HOME/Research/Challenges/I2B2-2010/Resources/conceptI2B2-2010d"
#                     TERMLIST    = "$HOME/Research/Challenges/I2B2-2010/Resources/term-ctx.txt"
#                     TERMLIST    = "$HOME/Research/Challenges/I2B2-2010/Data/Resources/Medication.txt"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/EPA-Term-Envir/Environment.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/NRDC-environmentalTerms/EnvironmentalTerms.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/Species/species.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/NatWildScenicRivers/NationalWildScenicRivers.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/EPA-Climate-Change/EPA-Climate-Change.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/DicoToxico/dicoToxicology.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/Ecology/Ecology.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/ECHA/glossary-echa.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/Toxicology/Toxicology.terms"
                    # TERMLIST    = "$HOME/Research/Projets/2011AIR-REACH/Resources/V07102011/EnvirEng/EnvironmentalEngineering.terms"
                    PerlModule  = "Alvis::TermTagger"
               </COMMANDS>
               <COMMANDS language=FR>
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/Brands.lst"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/products-V0.lst"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/DocumentsOut/products-V0-terms.txt"
#                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/"
#                     TERMLIST    = "$THHOME/Research/Projets/BQR/Fora/Resources/Criteres/V1/ListeCriteres-Baseline1.txt"
                    # TERMLIST    = "/home/thierry/Recherche/Divers/TestsNGR/terms_FR.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/dicoFood_hc-sc-gc-ca.termlist.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/aliments_LesCalories.termlist.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/aliments_LesCaloriesFree.termlist.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/aliments_CentreClauderer.termlist.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/Resources/aliments_bioweight.termlist.txt"
                    TERMLIST    = "$THHOME/Research/Misc/Skerou/Data/V0/DocumentsOut/products-V0-terms.txt"
                    TERMLIST    = "$NLP_resources_root/terms_FR.txt"
                    PerlModule  = "Alvis::TermTagger"
               </COMMANDS>
               <RESOURCE language=EN>
                    COLORFILE   = "$HOME/Research/Challenges/I2B2-2010/Config/colorHTMLUMLS.rc"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "I2B2AssertionIdentification"
            VERSION             = "0.1"
            COMMENTS            = "I2B2 Assertion Identification"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B2AssertionIdentification"
            <CONFIGURATION>
               <CONFIG language=EN>
                   CONFIGFILE  = "$HOME/Research/Challenges/I2B2-2010/Resources/AssertionIdentification-RUN1.rc"
                   SOMEBODYELSEFIRST = 1
                   ENUMERATIONIDENTIFICATION = 1
                   MARKERORDER = 0
                   <SEMANTICTYPES>
                       SEMANTICTYPE = "problem"
# #                        SEMANTICTYPE = "function"
#                        SEMANTICTYPE = "Behavior"
#                        SEMANTICTYPE = "Biologically Active Substance"
#                        SEMANTICTYPE = "Biologic Function"
#                        SEMANTICTYPE = "Body Space or Junction"
#                        SEMANTICTYPE = "Cell"
#                        SEMANTICTYPE = "Cell Component"
#                        SEMANTICTYPE = "Cell Function"
#                        SEMANTICTYPE = "Conceptual Entity"
#                        SEMANTICTYPE = "Finding"
#                        SEMANTICTYPE = "Functional Concept"
#                        SEMANTICTYPE = "Genetic Function"
#                        SEMANTICTYPE = "Individual Behavior"
#                        SEMANTICTYPE = "Mental or Behavioral Dysfunction"
#                        SEMANTICTYPE = "Mental Process"
#                        SEMANTICTYPE = "Molecular Function"
#                        SEMANTICTYPE = "Natural Phenomenon or Process"
#                        SEMANTICTYPE = "Organism Function"
#                        SEMANTICTYPE = "Organ or Tissue Function"
#                        SEMANTICTYPE = "Pathologic Function"
#                        SEMANTICTYPE = "Pharmacologic Substance"
#                        SEMANTICTYPE = "Phenomenon or Process"
#                        SEMANTICTYPE = "Physiologic Function"
#                        SEMANTICTYPE = "Qualitative Concept"
#                        SEMANTICTYPE = "Social Behavior"
#                        SEMANTICTYPE = "Temporal Concept"
#                        SEMANTICTYPE = "Tissue"
#                        SEMANTICTYPE = "Disease or Syndrome"
#                        SEMANTICTYPE = "Enzyme"
#                        SEMANTICTYPE = "Gene or Genome"
#                        SEMANTICTYPE = "Immunologic Factor"
#                        SEMANTICTYPE = "Organism Attribute"
                   </SEMANTICTYPES>
                   <SVMMULTICLASS>
#                       MODE = "LEARNING"
                      MODE = "CLASSIFY"
                      DESTDIR     = "$HOME/Research/Challenges/I2B2-2010/Training/RESULTS/AST/RUN28-SVM1"
                      MODEL = "$HOME/Research/Challenges/I2B2-2010/Training/RESULTS/AST/I2B2SVM27-train.model"
#                       USEPROPOSEDASSERTION = "EVERY"
#                       USEPROPOSEDASSERTION = "ATLEASTONEAST"
                       USEPROPOSEDASSERTION = "CONFLICTONLY"
                   </SVMMULTICLASS>
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
                   SVMMULTICLASS = "$NLP_tools_root/SVM-multiclass/svm_multiclass_classify"
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
#                    REXEXPMARKS = "$HOME/Recherche/Challenges/I2B2-2010/Resources/regexp_marqueurs_assertion"
#                    PATTERNSSYN = "$HOME/Research/Challenges/I2B2-2010/Resources/structure_syntaxique-nf-test.txt"
		     PATTERNS    = "$HOME/Research/Challenges/I2B2-2010/Resources/VMars2011/patterns_marqueurs_assertion"
		     MEDSECTION  = "$HOME/Research/Challenges/I2B2-2010/Resources/VMars2011/MedicationSections-v3.rc"
		     AFFIXLIST   = "$HOME/Research/Challenges/I2B2-2010/Resources/VMars2011/assertionMorpho.txt"
                     PATTERNSSYN = "$HOME/Research/Challenges/I2B2-2010/Resources/VMars2011/structure_syntaxique-nf.txt"
		</RESOURCE>
		<RESOURCE language=FR>
		</RESOURCE>
	     </CONFIGURATION>
	 </TOOL>
	 <TOOL>
	     NAME                = "I2B22010ConceptTagging"
	     VERSION             = "0.1"
	     COMMENTS            = "I2B2 2010 concept tagging based on results"
	     WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B22010ConceptTagging"
	     <CONFIGURATION>
		<CONFIG language=EN>
		</CONFIG>
		<CONFIG language=FR>
		</CONFIG>
		<COMMANDS language=EN>
		</COMMANDS>
		<COMMANDS language=FR>
		</COMMANDS>
		<RESOURCE language=EN>
		      GTDIR       = "$HOME/Research/Challenges/I2B2-2010/Training/GT"
		      I2B2MODULE  = "I2B2 2010 Post Processing"
		      INDEX       = "$HOME/Research/Challenges/I2B2-2010/Training/ProcessAnnot"
                     OUTPUTTYPE  = "C"
                                  # C, A, R
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "StanfordParser"
            VERSION             = "0.1"
            COMMENTS            = "Stanford Parser"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::StanfordParser"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
                  STANFORDPARSER_DIR  = "$NLP_tools_root/StanfordParser/stanford-parser-2010-07-01"
               <COMMANDS language=EN>
                 STANFORDPARSER_CMD   = "java -mx1500m -cp "$STANFORDPARSER_DIR/stanford-parser.jar:" edu.stanford.nlp.parser.lexparser.LexicalizedParser  -maxLength 200  -sentences newline -tokenized -tagSeparator /  -outputFormat "typedDependencies" $STANFORDPARSER_DIR/englishPCFG.ser.gz "
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
#         <TOOL>
#             NAME                = ""
#             VERSION             = "0.1"
#             COMMENTS            = ""
#             WRAPPER             = "Lingua::Ogmios::NLPWrappers::"
#             <CONFIGURATION>
#                <CONFIG language=EN>
#                </CONFIG>
#                <CONFIG language=FR>
#                </CONFIG>
#                <COMMANDS language=EN>
#                </COMMANDS>
#                <COMMANDS language=FR>
#                </COMMANDS>
#                <RESOURCE language=EN>
#                    CONFIGFILE  = ""
#                </RESOURCE>
#                <RESOURCE language=FR>
#                </RESOURCE>
#             </CONFIGURATION>
#         </TOOL>

        <TOOL>
            NAME                = "Distribution"
            VERSION             = "0.1"
            COMMENTS            = "Module for the distribution analysis"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::Distribution"
            <CONFIGURATION>
               <CONFIG language=EN>
                  BEFOREWINDOWSIZE = 10
                  AFTERWINDOWSIZE = 10
                  ALLTAGS = 0
                  # POSTAG for words
                  <POSTAGLIST>
                      POSTAG = "N.*"
                      POSTAG = "V.*"
                      POSTAG = "J.*"
                      POSTAG = "CD*"
                  </POSTAGLIST>
                  ALLWORDCOUNT = 1
                  PRINTTERM = 1
                  TERMINCONTEXT = 1
               </CONFIG>
               <CONFIG language=FR>
                  BEFOREWINDOWSIZE = 10
                  AFTERWINDOWSIZE = 10
                  ALLTAGS = 0
                  ALLTAGSCTXT = 0
                  # POSTAG for words
                  <POSTAGLIST>
                      POSTAG = "N.*"
                      POSTAG = "V.*"
                      POSTAG = "ADJ.*"
                      # POSTAG = "CD*"
                  </POSTAGLIST>
                  <POSTAGCTXTLIST>
                      POSTAG = "N.*"
                      POSTAG = "V.*"
                      POSTAG = "ADJ.*"
                      # POSTAG = "CD*"
                  </POSTAGCTXTLIST>
                  ALLWORDCOUNT = 0
                  PRINTTERM = 1
                  TERMINCONTEXT = 1
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

#         <TOOL>
#             NAME                = "Skill Identification"
#             VERSION             = "0.1"
#             COMMENTS            = "Identification of the skills in the text - related to the BQR ICED"
#             WRAPPER             = "Lingua::Ogmios::NLPWrappers::SkillIdentification"
#             <CONFIGURATION>
#                <CONFIG language=EN>
#                </CONFIG>
#                <CONFIG language=FR>
#                  SELECTION=0
# #                  SELECTION=1
#                </CONFIG>
#                <COMMANDS language=EN>
#                </COMMANDS>
#                <COMMANDS language=FR>
#                </COMMANDS>
#                <RESOURCE language=EN>
#                    CONFIGFILE  = ""
#                </RESOURCE>
#                <RESOURCE language=FR>
#                </RESOURCE>
#             </CONFIGURATION>
#         </TOOL>

        <TOOL>
            NAME                = "Skill production"
            VERSION             = "0.1"
            COMMENTS            = "Production of a ressource of Skills for the BQR ICED after term extractor"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::SkillProduction"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
                 SELECTION=0
#                  SELECTION=1
                 SKILLLIST=0
                 TERMS = 0
                 SIMPLETERMONLY = 0
                 EXPAND = 1
                 EXPAND_TERMINOLOGY = 1
                 EXPAND_SYNONYMY = 1
                 ALLTAGS = 0
                 THRESHOLDLIST = ""
                 <POSTAGLIST>
                     POSTAG = "N.*"
                     POSTAG = "V.*"
                     POSTAG = "ADJ.*"
                     # POSTAG = "CD*"
                 </POSTAGLIST>
                  <POSTAGCTXTLIST>
                      POSTAG = "N.*"
                      POSTAG = "V.*"
                      POSTAG = "ADJ.*"
                      # POSTAG = "CD*"
                  </POSTAGCTXTLIST>
                 <THRESHOLD resource="DISTRIBTHESAURUS"> 
                     A = 0.2
                     V = 0.02
                     N = 0.2
                     ADV = 0.2
                     TERMS = 0
                 </THRESHOLD>
                 <THRESHOLD type="SIZE"> 
                     A = 5
                     V = 5
                     N = 5
                     ADV = 5
                     TERMS = 1
                 </THRESHOLD>
                 SKILLDESCFILE = "$THHOME/Research/Projets/2011BQR-ICED/Txt/CriteresV1c/ListeCriteresRef2b3-selection.txt"
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
#                   CONFIGFILE  = ""
               </RESOURCE>
               <RESOURCE language=FR>
                   DISTRIBTHESAURUS = "$HOME/Research/Resources/FR/freDist/thesauri-1.0/thesaurus_french_ADV.txt"
                   DISTRIBTHESAURUS = "$HOME/Research/Resources/FR/freDist/thesauri-1.0/thesaurus_french_A.txt"
                   DISTRIBTHESAURUS = "$HOME/Research/Resources/FR/freDist/thesauri-1.0/thesaurus_french_N.txt"
                   DISTRIBTHESAURUS = "$HOME/Research/Resources/FR/freDist/thesauri-1.0/thesaurus_french_V.txt"
                   EXCEPTIONLIST = "$THHOME/Research/Projets/2011BQR-ICED/Txt/CriteresV1c/Exceptions.list"
                   SYNONYMY = "$HOME/Research/Projets/2011BQR-ICED/Fora/Resources/synonymy/syn07.ter.4.cat.txt"
                   TERMINOLOGY = "$HOME/Research/Resources/FR/Sports/Sport.termlist.txt"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "Skill Identification"
            VERSION             = "0.1"
            COMMENTS            = "Identification of the skills in the text - related to the BQR ICED"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::SkillIdentification"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
#                 SELECTION=NoSelection
#                  SELECTION=Selection
                  SELECTION=FullTermMatch
#                  PRINT=ALL
                  PRINT=WITHSKILLSONLY
                  SELECTION_SIZE = 2
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
                   CONFIGFILE  = ""
               </RESOURCE>
               <RESOURCE language=FR>
                   SKILLDESCFILE = "$THHOME/Research/Projets/2011BQR-ICED/Txt/CriteresV1c/ListeCriteresRef2b3-selection-968-expe3.txt"
                   SKILLLIST = "$THHOME/Research/Projets/2011BQR-ICED/Fora/Resources/Criteres/V1/ListeCriteres-terms.list"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "Skerou"
            VERSION             = "0.1"
            COMMENTS            = ""
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::Skerou"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
                   CONFIGFILE  = ""
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "I2B2 2010 Relation Acquisition"
            VERSION             = "0.1"
            COMMENTS            = "Module for the acquisition of semantic relations -- I2B2 2010"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::I2B22010RelationAcquisition"
            <CONFIGURATION>
               <CONFIG language=EN>
                   CONFIGFILE  = "$HOME/Research/Challenges/I2B2-2010/Resources/RelationAcquisition.rc"
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
#                    CONFIGFILE  = ""
                   RELATIONMARKS = "$HOME/Research/Challenges/I2B2-2010/Resources/I2B22010Relations.txt"
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "MorphoSemanticTagging"
            VERSION             = "0.1"
            COMMENTS            = "Semantic tagging based on morphologic and lexical clues"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::MorphoSemanticTagging"
            <CONFIGURATION>
               <CONFIG language=EN>
                   CONFIGFILE  = "$HOME/Research/Challenges/I2B2-2010/Resources/MorphoSemanticTagging.rc"
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
                   AFFIXLIST   = "$HOME/Research/Challenges/I2B2-2010/Resources/term-type.txt"
               </RESOURCE>
               <RESOURCE language=FR>
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "YaTeA"
            VERSION             = "0.5"
            COMMENTS            = "term extractor"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::YaTeA"
            <CONFIGURATION>
               <CONFIG language=EN>
                   YATEACONF = "$PLATFORM_ROOT/Conf/yatea-dev.rc"
#                   YATEACONF = "$PLATFORM_ROOT/Conf/yatea-i2b2.rc"
                   # YATEACONF = "$HOME/Research/Misc/InstitutPasteur/RiskFactors/Config/yatea-dev.rc"
               </CONFIG>
               <CONFIG language=FR>
#                    YATEACONF = "$PLATFORM_ROOT/Conf/yatea-dev-flemm2.rc"
                   YATEACONF = "$PLATFORM_ROOT/Conf/yatea-dev-fr2.rc"
#                    YATEACONF = "$PLATFORM_ROOT/Conf/yatea-dev-fr.rc"
                   # YATEACONF = "$THHOME/Research/Misc/Skerou/Data/V0/Config/yatea-dev-fr2.rc"
                   # YATEACONF = "$HOME/Research/Misc/InstitutPasteur/RiskFactors/Config/yatea-dev-fr.rc"
               </CONFIG>
               <COMMANDS language=EN>
                   PerlModule  = "Lingua::YaTeA"
               </COMMANDS>
               <COMMANDS language=FR>
                   PerlModule  = "Lingua::YaTeA"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "Flemm"
            VERSION             = "0.1"
            COMMENTS            = "POS tagger and morphological analyser"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::Flemm"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
                   PerlModule  = "Flemm"
                   FLEMM_BIN   = "export PERL5LIB=$NLP_tools_root/FLEMM:$PERL5LIB; $PERL $NLP_tools_root/FLEMM/flemm.pl"
                   FLEMM_PARAMETERS = " --tagger treetagger"
                   FLEMM_IN_PARAMETERS = "--entree"
                   FLEMM_OUT_PARAMETERS = "--sortie"
                   FLEMM_CMD   = "$FLEMM_BIN $FLEMM_PARAMETERS"
#                   FLEMM_CMD   = "flemm.pl --entree CORPUS_TTG --sortie CORPUS_FLEMM --tagger treetagger"
               </COMMANDS>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "LexicalSyntacticPatterns"
            VERSION             = "0.1"
            COMMENTS            = "Application of Lexical Syntactic Patterns"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::LexicalSyntacticPatterns"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
#                       MEDICATION = ""
#                       REASON = ""
                        PATTERNS = "$HOME/Platform/NLPtools/LSPatterns/LSPatterns-EN.list"
               </RESOURCE>
               <RESOURCE language=FR>
#                       MEDICATION = ""
#                       REASON = ""
                        PATTERNS = "$HOME/Platform/NLPtools/LSPatterns/LSPatterns-FR.list"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>
        <TOOL>
            NAME                = "Faster"
            VERSION             = "2.03"
            COMMENTS            = "Morphosyntactic term variant extractor"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::Faster"
            <CONFIGURATION>
               <CONFIG language=EN>
                   FASTRCONF = "$PLATFORM_ROOT/Conf/Fastr.conf-en"
                   MODE = "FREE"
#                   MODE = "CONTROLLED"
               </CONFIG>
               <CONFIG language=FR>
                   FASTRCONF = "$PLATFORM_ROOT/Conf/Fastr.conf-fr"
                   MODE = "FREE"
                   # MODE = "CONTROLLED"
               </CONFIG>
               FASTRBIN                = "$NLP_tools_root/FASTER/bin"
               FASTRCMD                = "$NLP_tools_root/FASTER/cmd"
               FASTRLIB                = "$NLP_tools_root/FASTER/lib"
               FASTREMPTYCONF          = "$FASTRLIB/Fastr.conf-empty"
               <COMMANDS language=EN>
                   FASTR                   = "$FASTRBIN/Fastr"
                   CONVERTCORPUS_CMD       = "$FASTRCMD/TreeTaggertoFastr.prl $FASTRLIB/TAGS-TreeTagger-en"
                   MAKEMETARULES_SW_CMD    = "$FASTRCMD/TermtoRules.prl $FASTRLIB/TAGS-TreeTagger-en | grep '^Word' | sort -u | $FASTRCMD/WordtoFamilies.prl $FASTRLIB/der-families-en -classes $FASTRLIB/sem-classes-en | sort -u"
                   MAKEMETARULES_TRM_CMD   = "$FASTRCMD/TermtoRules.prl $FASTRLIB/TAGS-TreeTagger-en | grep -v '^Word'"
                   CONVERTTERMLIST_CMD     = "$FASTRCMD/TreeTaggertoTerms.prl"
               </COMMANDS>
               <COMMANDS language=FR>
                   FASTR                   = "$FASTRBIN/Fastr"
                   CONVERTCORPUS_CMD       = "$FASTRCMD/TreeTaggertoFastr.prl $FASTRLIB/TAGS-TreeTagger-fr"
                   MAKEMETARULES_SW_CMD    = "$FASTRCMD/TermtoRules.prl $FASTRLIB/TAGS-TreeTagger-fr | grep '^Word' | sort -u | $FASTRCMD/WordtoFamilies.prl $FASTRLIB/der-families-fr -classes $FASTRLIB/sem-links-fr | sort -u"
                   MAKEMETARULES_TRM_CMD   = "$FASTRCMD/TermtoRules.prl $FASTRLIB/TAGS-TreeTagger-fr | grep -v '^Word'"
                   CONVERTTERMLIST_CMD     = "$FASTRCMD/TreeTaggertoTerms.prl"
               </COMMANDS>
               <RESOURCE language=EN>
                   CONTROLLED_TERMLIST    = ""
               </RESOURCE>
               <RESOURCE language=FR>
                   CONTROLLED_TERMLIST    = "$HOME/Research/Challenges/2012DEFT/Process/out/termino_appr.faster"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "DEFT 2012 Challenge"
            VERSION             = "0.1"
            COMMENTS            = "Post Processing for the DEFT 2012 Challenge"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::DEFT2012"
            <CONFIGURATION>
               <CONFIG language=EN>
               </CONFIG>
               <CONFIG language=FR>
                 MODE = LEARNING
                 LANGUAGE_RESTRICTION = 1
                 # MODE = TEST
                 # MODE = EVALUATE
#                 SEMANTICSELECTION = "dist:"
                 # KEEPBITERMS = 1
                 # SEMANTICSELECTION = "dist:10"
#                 SEMANTICSELECTION = "Freq:"
                 SEMANTICSELECTION = ""
                 DESTDIR     = "$HOME/Research/Challenges/2012DEF/Process/T1/Training/outSVN"
#                 MODEL = "$HOME/Research/Challenges/I2B2-2010/Training/RESULTS/AST/I2B2SVM27-train.model"
                 SELECTION = "keywords"
                 # SELECTION = "100%"
#                 SORT = "positionDistMid:Freq"
#                 SORT = "cantf"
#                 SORT = "canFreq"
#                 SORT = "positionCos:tf;cantf"
                 SORT = "positionCos:tf-idf"
#                SORT = "CValue:iTer"
#                 CANONICALFORMSORT = "NormFreq"
                 FILTER = "ADJ"
                FILTER = "CANONICALFORMBEFORE"
                FILTER = "CANONICALFORMAFTER"
#                 FILTER = "TERMINO"
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
#                   SVMMULTICLASS = "$NLP_tools_root/SVM-multiclass/svm_multiclass_classify"
               </COMMANDS>
               <RESOURCE language=EN>
                   CONFIGFILE  = ""
               </RESOURCE>
               <RESOURCE language=FR>
                   STOPWORDS = "$HOME/Research/Resources/FR/Dico/MotsVides/antidico.txt"
#                   STOPWORD = "$HOME/Research/Resources/FR/Dico/MotsVides/stopword.fr"
                   TERMINOLOGY = "$HOME/Research/Challenges/2012DEFT/Corpus/T1/corpus-appr-t1_deft2012/termino_appr.txt"
                   # TERMINOLOGY = "$HOME/Research/Challenges/2012DEFT/Process/T2/ref_appr-piste2-termino.txt"
                   # TERMINOLOGY = "$HOME/Research/Challenges/2012DEFT/Process/T1/ref_appr-piste1-termino.txt"
                   # TERMINOLOGY = "$HOME/Research/Challenges/2012DEFT/Process/ref_appr-piste1-piste2-termino.txt"
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

        <TOOL>
            NAME                = "Term Expansion"
            VERSION             = "0.1"
            COMMENTS            = "Term list expansion with semantic resources"
            WRAPPER             = "Lingua::Ogmios::NLPWrappers::TermExpansion"
            <CONFIGURATION>
               <CONFIG language=EN>
                 EXPAND_SYNONYMY = 1
                 TERMS = 1
               </CONFIG>
               <CONFIG language=FR>
                 EXPAND_SYNONYMY = 0
                 TERMS = 0
               </CONFIG>
               <COMMANDS language=EN>
               </COMMANDS>
               <COMMANDS language=FR>
               </COMMANDS>
               <RESOURCE language=EN>
                   SYNONYMY = "$HOME/Research/Challenges/2012I2B2/Resources/WordNet-3.0b.txt"
               </RESOURCE>
               <RESOURCE language=FR>
#                   SYNONYMY = ""
               </RESOURCE>
            </CONFIGURATION>
        </TOOL>

</NLP_tools>

<CONVERTERS>
text/plain = text2xhtml  <

text/html = 

www/unknown = 
#text/plain ; ; GuessText

text/x-tex = tth -g -w1 -r <  

application/x-tex =  tth -g -w1 -r < 
#text/x-tex ; untex -a -e -giso ; TeXText
#application/x-tex ; untex -a -e -giso ; TeXText
#text/x-tex ;  ; TeX
#application/x-tex ; ; TeX

application/pdf = pdftohtml -i -noframes -nomerge -stdout 
#application/pdf ; pstotext ; Text
application/postscript = pstotext 
application/msword = antiword -t 

application/vnd.ms-excel =  xlhtml -fw 

application/vnd.ms-powerpoint = ppthtml 
application/powerpoint = ppthtml 

application/rtf = unrtf --nopict --html 
# image/gif ; ; Image
# image/jpeg ; ; Image
# image/tiff ; ; Image
application/xml = 

<STYLESHEET>

default = xsltproc /etc/ogmios/xsl/Default.xsl

</STYLESHEET>

SupplMagicFile = $THHOME/Research/Programs/Ogmios2/Lingua-Ogmios/etc/ogmios/mime/magic.TeX
# SupplMagicFile = $HOME/Recherche/Program/Ogmios2/Lingua-Ogmios/etc/ogmios/mime/magic.TeX
# SupplMagicFile = /etc/ogmios/mime/magic.TeX

StoreInputFiles = 0

</CONVERTERS>

